package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"`!0````!$``9<````#0``,*4```````T`"``
M"0`H`!\`'@````8````T$```-!```#0```$@```!(`````4````$`````P``
M`500``%4$``!5`````T````-````!`````$````!`````!`````0``````"Y
ML```N;`````%``$```````$``+[0$`&^T!`!OM````*(```2T`````8``0``
M`````@``OO`0`;[P$`&^\````0````$`````!@````0````$```!9!```600
M``%D````1````$0````$````!&1TY5```+EP$`"Y<!``N7`````4````%```
M``0````$9'3E40``````````````````````````````!@````1D=.52``"^
MT!`!OM`0`;[0```!,````3`````$`````2]L:6(O;&0N<V\N,0`````````$
M````$`````%'3E4```````````(````&````#P````0````4`````T=.50`N
M"0(NS%UV53"[-3VC.A@+:O!O2````&$```!T````"P``````````````0P``
M``````!(````1P````````!+````6P```#X````Y````3`````,```!8````
M`````#$```!@````5````&H```!L````:`````0````L```````````````J
M````9````!X``````````````&4```!)````9@````D```!P````40```',`
M````````3@`````````?`````````'$`````````4````&T`````````````
M`&<````H`````````#H``````````````%H````U````0````$8`````````
M`````!(`````````/P``````````````(P`````````<````,`````P````R
M````*0```%,``````````````%P```!K````/````%\```!-````.P```#0`
M````````1````````````````````%4```!C`````````$4```!>````0@``
M`#T````G`````0``````````````````````````````````````````````
M``````````````````````````!/````````````````````````````````
M````#P```!0```!A`````````````````````````!,``````````````!$`
M````````&0````````````````````````!6`````````%<`````````:0``
M````````````$```````````````%P```!L`````````)@````4````D````
M"``````````O````)0````X````=`````````&(````A`````````!H````*
M``````````````!!````#0`````````S````+@```&X```!R````70``````
M````````2@````<`````````````````````````````````````````60``
M`"(``````````````&\````8`````````#8`````````*P``````````````
M```````````6````!@```!4`````````4@`````````````````````````W
M``````````(`````````(````"T````X````)0```$\````(````"`00$`"`
M!$`E`0``J*@!AJ("(`1`*00H3T<RHC@(#(2*````3P```%``````````````
M``````!2````5````%4```!6````5P```%@`````````60```%L```!<````
M`````%T```````````````````!>````80``````````````8@```&0```!E
M````9P````````!I````:P``````````````;0```&X```!Q`````'&RU<DM
M1][.2?O@HP[OT^IKH]VGMIO%+Y[CS=M[7^_G@9SYA]9#"6L+ESH,Q@681Y`%
MB<6>XA0-#N3_(6^+`;)`G+G$?)I_:YN<J7\?W\5N'%AQV7R2X[M\U&34P.-+
MK>W;8C(*`J?A9LRO9FM*\'L!QD?B[-5%0\6.07VI8<J4+#_EPB`+(J$=T]OR
M8&RA^@[QC;D````````````````````````"_P``````````$@```````+$`
M`````````!(```````.-```````````2```````#>```````````$@``````
M`:$``````````!(```````.]```````````2```````">@``````````$@``
M`````!$``````````"`````````@```````````@```````#?@``````````
M$@```````8T``````````!(```````/>```````````2```````!;@``````
M````$@```````8```````````!(```````,O```````````2```````"W@``
M````````$@```````BP``````````!(```````#]```````````2```````"
M'```````````$@```````Z(``````````!(```````'*```````````2````
M```$2```````````$@``````!`T``````````!(```````+K```````````2
M```````"Y@``````````$@```````I@``````````!(```````'J````````
M```2```````!I@``````````$@```````C4``````````!(```````/+````
M```````2```````$.@``````````$@```````2\``````````!(```````/6
M```````````2````````-```````````$@```````^@``````````!(`````
M``%=```````````2````````R```````````$@``````!!H``````````!(`
M``````.V```````````2```````$!@``````````$@```````YL`````````
M`!(```````-Q```````````2```````%&P``````````$@```````4$`````
M`````!(```````/V```````````2```````"7```````````$@```````U<`
M`````````!(```````,0```````````2```````"3@``````````$@``````
M`ZD``````````!(```````*1```````````2```````!JP``````````$@``
M`````V```````````!(```````.P```````````2```````#E```````````
M$@```````.P``````````!(```````!"```````````2```````#_0``````
M````$@``````!#(``````````!(```````#7```````````2```````!_@``
M````````$@```````H4``````````!(```````%0```````````2```````#
MA@``````````$@```````T8``````````!(```````+7```````````2````
M```!'0``````````$@``````!"0``````````!(```````)#```````````2
M````````5```````````$@```````=@``````````!(```````!C````````
M```2```````$00``````````$@```````(\``````````!(```````-.````
M```````2```````#00``````````$@```````'@``````````!(```````$+
M```````````2```````!MQ``4Z``````$@``````!9D0`$(P```*"!(```T`
M``7%$``W8````D02```-```$LA``6;``````$@``#@``!%P0`<%@````!"$`
M`!L```2*$``S(`````P2```-```%11``4?````"T$@``#0``!5H0`%U\``!;
MZA$```\```"@$`!5<``````2```````%,!`!P4``````$```&0``!3(0`<%`
M`````"```!D```55$`'!4`````01```:```$6Q`!P6`````$(0``&P``!*@0
M`%'@````!!(```T```6X$``_H````I`2```-```$SA``*O````"<$@``#0``
M!%H0`<%@````!!$``!L```15$``\X````K02```-```%"1``.;`````X$@``
M#0``!200`#P`````V!(```T```1Y$`'!6``````0`/_Q```$A1`!T:``````
M$`#_\0``!+@0`$Q````$C!(```T```,@$`!9^`````01```/```%-A``&7``
M```D$@``#0``!-P0`#(P````Z!(```T```3]$``Y\````@@2```-```":A``
M56``````$@``````!)L0`!K@````:!(```T```1R$`'!6``````0`/_Q```%
M:1``+5````!4$@``#0``!/(0`D%0`````!```!H```4]$`!0T````$@2```-
M```%A1`!P50````$$0``&@```J,0`<%P````$Q$``!L```6F$``UP````9@2
M```-```%/Q``&1P`````$@``#`!L:6)P97)L+G-O+C4N,3``7U]G;6]N7W-T
M87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?
M27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA9W-?
M<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!0
M97)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C
M;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T
M<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E
M;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?
M;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E
M<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?
M9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`
M;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D
M`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L
M:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI
M=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`
M=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R
M;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M8W!Y`%]?<W1R;F-P>5]C:&L`
M7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?;&]C`&=E
M='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`')E861D:7(V-`!?
M7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A
M<G1?;6%I;@!?7V5N=FER;VX`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?
M<W1A<G0`7V5N9`!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI
M8F-?8W-U7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE
M86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]31$%?0D%315\`<&%R7V1I<FYA
M;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7U]D
M871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`&YA;65?;&]A9%]M
M>5]P87)?<&P`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A
M9%]M>5]P87)?<&P`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A
M<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,P!'
M3$E"0U\R+C,N,@!'3$E"0U\R+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP````
M``(````#``,````$``````````,````%```````&``<``````````P````,`
M!``"``(```````,````%``,````#````"```````!0`#``,``P`#``,````#
M`````P`"`````P`#````"0`#``,```````,``P````````````,``P`'````
M"0````````````,````#``,``````````0`!``$``P`!``$``0````$``0`!
M``,``0`!``$``P`!``$``0`!``$``0`!``$``0`!`````0`!``$``0`!``$`
M```!``$````!``8```,6````$````'`-:6D4````"0``!=(````0#6EI$P``
M``@```7<````$`EI&7(````&```%Y@```!`-:6D2````!0``!?(````0"6D9
M=`````0```7\````$`UI:1`````#```&"````````0`"```"QP```!``````
M#6EI$@````<```7R````$`UI:1`````"```&"``````0`;_P```(%``````0
M`<%@``!?$P`````0`<%P``!Q$P`````0`<`````!%0`````0`<`$```"%0``
M```0`<`(```#%0`````0`<`,```$%0`````0`<`0```%%0`````0`<`4```&
M%0`````0`<`8```'%0`````0`<`<``!/%0`````0`<`@```(%0`````0`<`D
M```*%0`````0`<`H```+%0`````0`<`L```,%0`````0`<`P```-%0`````0
M`<`T```.%0`````0`<`X```/%0`````0`<`\```0%0`````0`<!````1%0``
M```0`<!$```2%0`````0`<!(```3%0`````0`<!,```4%0`````0`<!0```5
M%0`````0`<!4```6%0`````0`<!8```7%0`````0`<!<```8%0`````0`<!@
M```9%0`````0`<!D```:%0`````0`<!H```;%0`````0`<!L```<%0`````0
M`<!P```=%0`````0`<!T```>%0`````0`<!X```?%0`````0`<!\```@%0``
M```0`<"````A%0`````0`<"$```B%0`````0`<"(```C%0`````0`<",``!J
M%0`````0`<"0``!7%0`````0`<"4```D%0`````0`<"8```E%0`````0`<"<
M```F%0`````0`<"@```G%0`````0`<"D```H%0`````0`<"H```I%0`````0
M`<"L```J%0`````0`<"P```K%0`````0`<"T```L%0`````0`<"X```M%0``
M```0`<"\```N%0`````0`<#````O%0`````0`<#$```P%0`````0`<#(```Q
M%0`````0`<#,```R%0`````0`<#0```S%0`````0`<#4```T%0`````0`<#8
M```U%0`````0`<#<```V%0`````0`<#@```W%0`````0`<#D```X%0`````0
M`<#H```Y%0`````0`<#L```Z%0`````0`<#P```[%0`````0`<#T```\%0``
M```0`<#X```]%0`````0`<#\```^%0`````0`<$````_%0`````0`<$$``!`
M%0`````0`<$(``!!%0`````0`<$,``!"%0`````0`<$0``!#%0`````0`<$4
M``!$%0`````0`<$8``!%%0`````0`<$<``!&%0`````0`<$@``!'%0`````0
M`<$D``!(%0`````0`<$H``!)%0`````0`<$L``!*%0`````0`<$P``!+%0``
M```0`<$T``!,%0`````0`<$X``!-%0`````0`<$\``!.%0````"4(?_P?`@"
MII`!`!23P0`(0I\`!7_(`J8_W@`".]ZFQ(`>__PO@```09X`"$@`.FE(``$E
M2``Y88`!`!1\"`.F@\$`"#@A`!!.@``@``````````!\*0MX5"$`-C@```"4
M(?_P?`@#II`!```]`!``A:A9Z$@`.O````````````````"4(?_@?`@"II.!
M`!"3H0`4/X`0`I`!`"23P0`8D^$`'(@<P80O@```0)X`9#_@$`(_H!`"/\`0
M`CN]OM@[WK[<?]WP4($_P8A_WA9P.][__W^)\$!`G``P.__!B&`````Y*0`!
M52`0.I$_``!\'0`N?`D#IDZ`!"&!/P``?XGP0$&<_^`X```!F!S!A(`!`"2#
M@0`0@Z$`%(/!`!A\"`.F@^$`'#@A`"!.@``@8````)0A__!\"`*FD`$`%(`!
M`!0X(0`0?`@#IDZ``"!@````/2`0`I0A__!\"`*F.&F^X)`!`!2`";[@+X``
M`$&>`!P](```.`D``"^```!!G@`,?`D#IDZ`!"&``0`4."$`$'P(`Z9.@``@
M8````&````"4(?_P?`@"II`!`!2``0`4."$`$'P(`Z9.@``@`````)0A__!\
M:AMXB`,``"^```!!G@!,/6`0`#DC``&!:UG\B6L``$@``!Q@````8````(@)
M```Y*0`!+X```$&>`"!_@%@`0)[_[(@)``!]*DMX.2D``2^```!`GO_H?4-3
M>#@A`!!.@``@8````&````"4(?Z@.```$'P)`Z8Y0P`<.2```).!`5"3H0%4
MD\$!6)/A`5PY80`08````&````!\"D@N?`M)+CDI``1"`/_T.2$`1#D!`41@
M````8````(%I_^R`"0``@4G_U'U@`GB!:?_,?`!2>'P`6GA4``@^D`D`##DI
M``1_B4``0)[_U("#`!"#P0`0@`,``(##``2`XP`(@*,`#'_$\A2!`0`4@8$`
M&#_>6H)4RO`^5!\H/GRK,'B#@0`<?05"%'SI,#@[WGF9?6E+>'_>^A1]2P`X
M?/\`>#T(6H)]/DH4?^M;>#D(>9E]AV(4?0A:%%4K*#Y]:%H4/8Q:@E0(\#Y5
M/O`^?5](>%5]*#Y]*4`X.8QYF7V,ZA1_Z4MX/YQ:@GTL2A2!@0`@?1U8>'U_
M\#@[G'F9?[_[>'U<4A0]C%J"@X$`)'_J^A15*B@^?5]2%#F,>9E5?_`^55TH
M/G_+2'A]C$(452CP/GTI^#A]C.H4?6E+>#^<6H)]+$H4@8$`*'_]4'A]2T`X
M.YQYF7^K6WA_W/(4/8Q:@H.!`"Q_WEH452LH/GU^6A0YC'F955[P/E5]*#Y]
M"DAX?8SZ%%4_\#Y]*?`X?8SJ%'U)2W@_G%J"?2Q*%(&!`#!_W5AX?6KX.#N<
M>9E_JE-X?1Q"%#V,6H*#@0`T?0A2%%4J*#Y]2%(4.8QYF55H\#Y572@^?^M(
M>'V,\A15/O`^?2E`.'V,ZA1]:4MX/YQ:@GTL2A2!@0`X?1U0>'U+\#@[G'F9
M?ZM;>'_\^A0]C%J"@X$`/'__6A15*R@^?7]:%#F,>9E57_`^57TH/G_*2'A]
MC$(452CP/GTI^#A]C.H4?4E+>#^<6H)]+$H4@8$`0'_]6'A]:D`X.YQYF7^J
M4WA_W/(4/8Q:@H.!`$1_WE(452HH/GU>4A0YC'F957[P/E5=*#Y]"TAX?8SZ
M%%4_\#Y]*?`X?8SJ%'UI2W@_G%J"?2Q*%(&!`$A_W5!X?4OX.#N<>9E_JUMX
M?1Q"%#V,6H*#@0!,?0A:%%4K*#Y]:%H4.8QYF55(\#Y5?2@^?^I(>'V,\A15
M/O`^?2E`.'V,ZA1]24MX/YQ:@GTL2A2!@0!0?1U8>'UJ\#@[G'F9?ZI3>'_\
M^A0]C%J"@X$`5'__4A15*B@^?5]2%#F,>9E5?_`^55TH/G_+2'A]C$(452CP
M/GTI^#A]C.H4?6M+>#^<6H)];%H4@8$`6'_]4'A]24`X.YQYF7^I2WA_W/(4
M/8Q:@H.!`%Q_WDH456DH/GT^2A152O`^.8QYF54]*#Y]'EAX?8SZ%%5_\#Y]
M:U`X?8SJ%'_>6WA]74AX?2OX.'^]6W@_G%J"@6$`8#N<>9E_S/(4@8$`J'T<
M0A0]:V[:?XCJ%#D+ZZ%7RR@^52GP/GU\6A2#@0!D?3WZ>'U(4A17R/`^/YQN
MVG^^\GA_JO(4.YSKH7T>2GA5:B@^?5U2%'^<^A2#H0!H57_P/G_+6GA_G%H4
M54LH/GU\6A0_O6[:@X$`;'_^0G@[O>NA?[U*%#^<;MI52?`^?\I2>'^]4A1]
M/OIX56HH/CN<ZZ%]75(4?YQ"%(.A`'!5:/`^?\M:>'^<6A152R@^?7Q:%#^]
M;MJ#@0!T?1Y*>#N]ZZ%_O?H4/YQNVE5?\#Y_RE)X?[U2%'_^0GA5:B@^.YSK
MH7U=4A1_G$H4@Z$`>%5I\#Y_RUIX?YQ:%%5+*#Y]?%H4/[UNVH.!`'Q]/OIX
M.[WKH7^]0A0_G&[:54CP/G_*4GA_O5(4?1Y*>%5J*#X[G.NA?5U2%'^<^A2#
MH0"`57_P/G_+6GA_G%H454LH/GU\6A0_O6[:@X$`A'_^0G@[O>NA?[U*%#^<
M;MI52?`^?\I2>'^]4A1]/OIX56HH/CN<ZZ%]75(4?YQ"%(.A`(A5:/`^?\M:
M>'^<6A152R@^?7Q:%#^];MJ#@0",?1Y*>#N]ZZ%_O?H4/YQNVE5?\#Y_RE)X
M?[U2%'_^0GA5:B@^.YSKH7U=4A1_G$H4@Z$`D%5I\#Y_RUIX?YQ:%%5+*#Y]
M?%H4/[UNVH.!`)1]/OIX.[WKH7^]0A0_G&[:54CP/G_*4GA_O5(4?1Y*>%5J
M*#X[G.NA?5U2%'^<^A2#H0"857_P/G_+6GA_G%H454LH/GU\6A0_O6[:@X$`
MG#N]ZZ%__D)X?[U*%#^<;MI52?`^.YSKH7_*4GA]/OIX?[U2%'^<0A15:B@^
M56CP/G_+6GB#P0"@?5U2%'T=2GA_G%H4/]YNVE5+*#X[WNNA?7Q:%'_^^A15
M7O`^?ZI2>(.A`*0]C&[:?Y]2%'_?0G@_O6[:56HH/CN]ZZ%]7%(4@X$`K'^]
M2A15:?`^?^M:>#F,ZZ%]/_)X?[U:%%5+*#Y]C$(4?7U:%%5(\#Y_ZE)X57\H
M/GV,4A1]'4IX?^SZ%(&!`+`_G&[:56KP/CN<ZZ$]C(\<?ZM:>#F,O-Q]74`X
M?2Q*%(&!`+1_W/(4?5Q#>'_>6A0]C(\<5^OP/CF,O-Q_G/@X?0Q"%(&!`+A7
M_R@^?][Z%'^?ZW@]C(\<?7U0.#F,O-Q]?%-X?4Q2%(&!`+Q_G/`X?^GZ%%?)
M\#X]C(\<5]XH/CF,O-Q___(4?Y[K>'T]6#A]/%MX?6Q:%(&!`,!_G/@X?\CR
M%#V,CQQ7Z/`^.8R\W%?_*#Y_WOH4?Y_K>'T=2#A]'$MX?2Q*%(&!`,1_G/`X
M?^KZ%%?*\#X]C(\<5]XH/CF,O-Q___(4?Y[K>'U=0#A]7$-X?0Q"%(&!`,A_
MG/@X?\OR%#V,CQQ7Z_`^.8R\W%?_*#Y_WOH4?Y_K>'U]4#A]?%-X?4Q2%(&!
M`,Q_G/`X?^GZ%%?)\#X]C(\<5]XH/CF,O-Q___(4?Y[K>'T]6#A]/%MX?6Q:
M%(&!`-!_G/@X?\CR%#V,CQQ7Z/`^.8R\W%?_*#Y_WOH4?Y_K>'T=2#A]'$MX
M?2Q*%(&!`-1_G/`X?^KZ%%?*\#X]C(\<5]XH/CF,O-Q___(4?Y[K>'U=0#A]
M7$-X?0Q"%(&!`-A_G/@X?\OR%#V,CQQ7Z_`^.8R\W%?_*#Y_WOH4?Y_K>'U]
M4#A]?%-X?4Q2%(&!`-Q_G/`X?^GZ%%?)\#X]C(\<5]XH/CF,O-Q___(4?Y[K
M>'T]6#A]/%MX?6Q:%(&!`.!_G/@X?\CR%#V,CQQ7Z/`^.8R\W%?_*#Y_WOH4
M?Y_K>'T=2#A]'$MX?2Q*%(&!`.1_G/`X?^KZ%%?*\#X]C(\<5]XH/CF,O-Q_
M__(4?Y[K>'U=0#A]7$-X?0Q"%(&!`.A_G/@X?\OR%#V,CQQ7Z_`^.8R\W%?_
M*#Y_WOH4?Y_K>'U]4#A]?%-X?4Q2%(&!`.Q_G/`X?^GZ%%?)\#X]C(\<5]XH
M/CF,O-Q___(4?Y[K>'T]6#A]/%MX?6Q:%(&!`/!_G/@X?\CR%#V,CQQ7Z/`^
M.8R\W%?_*#Y_WOH4?Y_K>'T=2#A]'$MX?2Q*%(&!`/1_G/`X?^KZ%%?*\#X]
MC(\<5]XH/CF,O-Q___(4?Y[K>'U=0#A]7$-X?0Q"%(&!`/A_G/@X?\OR%%?K
M\#Y7_R@^?][Z%#V,CQQ_G^MX?7Q3>'U]4#A_G/`X?^GZ%#F,O-Q7R?`^5]XH
M/G__\A1]3%(4@8$`_'^>ZWA]/%MX?3U8.'^<^#A_R/(45^CP/E?_*#X]C(\<
M?][Z%'^?ZWA]'4MX?XKZ%'^]\#A]'T@X.8R\W%?**#Y]7%(4?[_[>(.A`0!7
MWO`^?6Q:%'V+^A1_WT)X54LH/G__4GA];%H4/[W*8U5,\#Z!00$$.[W!UGT]
M2A0]2LIC?ZGZ%#E*P=9]B?)X57\H/GT*0A1__?H456KP/GTK6GB!(0$(?ZA:
M%%?K*#Y]?5H4/2G*8X.A`0Q]2&)X.2G!UG_)\A0_O<IC5^GP/GT?^GA_WOH4
M56@H/GT_4G@[O<'6?1Y"%'^]8A2#P0$056SP/G_K6GA_O5H450LH/GU]6A0_
MWLIC@Z$!%'V?2G@[WL'6?]Y2%#^]RF-5"O`^?^A">'_>0A1]7V)X56@H/CN]
MP=9]'D(4?[U*%(/!`1A5:?`^?^M:>'^]6A15"R@^?7U:%#_>RF.#H0$<?3]2
M>#O>P=9_WF(4/[W*8U4,\#Y_Z$)X?]Y"%'V?2GA5:"@^.[W!UGT>0A1_O5(4
M@\$!(%5J\#Y_ZUIX?[U:%%4+*#Y]?5H4/][*8X.A`21]7V)X.][!UG_>2A0_
MO<IC50GP/G_H0GA_WD(4?3]2>%5H*#X[O<'6?1Y"%'^]8A2#P0$H56SP/G_K
M6GA_O5H450LH/GU]6A0_WLIC@Z$!+'V?2G@[WL'6?]Y2%#^]RF-5"O`^?^A"
M>'_>0A1]7V)X56@H/CN]P=9]'D(4?[U*%(/!`3!5:?`^?^M:>'^]6A15"R@^
M?7U:%#_>RF.#H0$T?3]2>#O>P=9_WF(4/[W*8U4,\#Y_Z$)X?]Y"%'V?2GA5
M:"@^.[W!UGT>0A1_O5(4@\$!.%5J\#Y_ZUIX?[U:%%4+*#Y]?5H4/][*8X.A
M`3Q]7V)X.][!UG_>2A0_O<IC50GP/G_H0GA_WD(4?3]2>%5H*#X[O<'6?1Y"
M%'^]8A2#P0%`56SP/G_K6GA_O5H450LH/GU]6A0_WLIC@Z$!1#O>P=9]GTIX
M?]Y2%#^]RF-5"O`^.[W!UG_H0GA]7V)X?]Y"%'^]2A15:"@^56GP/G_K6GB#
MX0%(?1Y"%(/!`4Q_O5H450LH/C__RF-_P/(4.__!UGT@4GA]?5H4?9]B%#_>
MRF-5'_`^?`A">#O>P=9]C$(456`H/G_H2GA]7E(4?`P"%'T(6GA]"D(456OP
M/E0**#Y\I?H4?4A2%'P&`A1\YUH4?21*%)%#``"0`P`$@X$!4(.A`520XP`(
MD*,`#(/!`5B#X0%<."$!8)$C`!!.@``@8````&````!@````E"'_T'P(`J:3
M@0`@DV$`''Q\&WF300`8D`$`-'R:(WB3H0`DD\$`*)/A`"Q`@@`T.&```(`!
M`#2#00`8@V$`'(.!`"!\"`.F@Z$`)(/!`"B#X0`L."$`,$Z``"!@````/2`0
M`H-IP6`OFP``09[_Q(@<```O@```09X`F"^``#U!G@"0?YWC>(P=``$O@```
M+P``/4&>``A`FO_P?[SH4(/[```OGP``09[_B']^VWA_X_MX?X3C>'^EZWA(
M`"SU+X,``$">`!!\'^BN+X``/4&>`""'_@`$+Y\``$">_]1+__]08````&``
M``!@````?]OP4#A]``%_WA9PD]H``'Q_&A1+__\P8````&`````[H```2___
MC&````!@````E"'_X'P(`J:0`0`D.($`'$S&,8)+__[-@`$`)#@A`"!\"`.F
M3H``(&````!@````E"'_X'P(`J:3X0`<D`$`)#_@$`*`?\%,+X/__T&>`"2`
M`0`D@^$`'#@A`"!\"`.F3H``(&````!@````8````#Q@$``X8UJ(3,8Q@DO_
M_X4L`P``08(`/(AC```O@P``09X`,&AC`#!\8P#05&,/_I!_P4R``0`D@^$`
M'#@A`"!\"`.F3H``(&````!@````.&```)!_P4Q+___<8````)0A_]!\"`*F
MDZ$`))/!`"@_H!`"?'X;>)/A`"R0`0`T.[W!8#OA`!Q(```H8````($A`!R`
M'0``52D0.GT@2A2$"0`$D`G__"^```!`GO_T?\/S>'_D^WA,QC&"2__]M2^#
M``!`GO_,@`$`-(.A`"2#P0`H@^$`+#@A`#!\"`.F3H``(&````!@````8```
M`)0A[]`\8!``?`@"ICAC6I23@1`@DZ$0)'R\*WA\G2-XD\$0*)/A$"PXH`__
MD`$0-#O!`!Q_Q/-X@`*/^)`!$!PX````2``J?7Q_&WE`@0"X.!___SEA$"!]
M*P(4B2GO_"^)``!!G@!\?\/S>#B``"]_Y?MX2``JK2^#``!!G@"(.&```$@`
M*PV`8P``2``G]7^DZWA_Q?-X?^;[>$@`*46``1`<@2*/^'P`2GDY(```0((`
M=(`!$#2#@1`@@Z$0)(/!$"A\"`.F@^$0+#@A$#!.@``@8````&````!@````
M+X```$&>`"!\'P-X?\/S>#B``"]_Y?MX2``J*2^#``!`GO^`.&```$@`*HF`
M8P``2``G<7^DZWA_A>-X2``G-4O__X!(`"E-8````&````"4(?_P.&```'P(
M`J:0`0`42``J48!C``!(`"<Y.(#__T@`)X$X8```2``J.8!C``!(`"<A/(`0
M`#B@```XA"VP2``J@8`!`!0X(0`0?`@#IDZ``"!@````8````&````"4(?_@
M.&```'P(`J:3X0`<D`$`)$@`*>V`8P``2``FU4@`)7&!(P``.&```(/I``1(
M`"G1@&,``$@`)KE(`"8%B`,``#A@``"8'P`82``IM8!C``!(`":=2``E.8$C
M```X8```@^D`!$@`*9F`8P``2``F@4@`)=V!(P``.&```(`)`!!4`$W^L!\`
M&D@`*76`8P``2``F74@`)/F!(P``.&```(/I``1(`"E9@&,``$@`)D$\@!``
M.*```#B$6\!(`"C!D'\`'#A@``!(`"DU@&,``$@`)AU(`"2Y@2,``#A@``"#
MZ0`$2``I&8!C``!(`"8!2``E+8`#```X8```D!\`($@`*/V`8P``2``EY4@`
M)(&!(P``.&```(/I``1(`"CA@&,``$@`)<E(`"?E.````($C```OB0``09X`
M(#A@``!(`"B]@&,``$@`):5(`"?!@2,``(`)`&R0'P`D.&```#O@``!(`"B9
M@&,``$@`)8%(`"0=@2,``#A@``"!*0`$D^D`*$@`*'F`8P``2``E84@`(_V!
M(P``.&```($I``23Z0`L2``H68!C``!(`"5!2``CW8$C```X8```@^D`!$@`
M*#V`8P``2``E)4@`)_&``P``D!\`,(`!`"2#X0`<."$`('P(`Z9.@``@E"'_
M8'P(`J:3X0"<D\$`F'Q_&WF0`0"DDV$`C).!`)"3H0"408(`$(@?```O@```
M0)X`,(`!`*2#80",@X$`D(.A`)1\"`.F@\$`F(/A`)PX(0"@3H``(&````!@
M````2``E,7Q^&WE!@O_,/V`0`#N!`!@[>UJD8````&````!_P_-X2``E?7QH
M&WE_X_MX08(`L(@(`!,Y"``3+X``+D&>`."1`0`,2``EB8$!``Q\?1MX?0-#
M>$@`)7E\?1H4.&,``D@`)@V!`0`,?V;;>'_G^W@X@``!.*#__WQ]&WA,QC&"
M2``F_7^%XWA_I.MX.&```T@`(TTO@___?Z/K>$&>`!2``0`H5``$)B^`0`!!
MG@"@2``E+7^CZWA(`"0E?\/S>$@`)-U\:!MY?^/[>$""_V1@````8````&``
M``!_P_-X2``E37_C^WA(`"6U@`$`I(-A`(R#@0"0@Z$`E'P(`Z:#P0"8@^$`
MG#@A`*!.@``@8````&````!@````B`@``2^```!!GO[X+X``+D">_Q2("``"
M+X```$&>_N1+__\$8````&````!@````2__^44O__V1@````8````)0A_^!\
M"`*FD^$`')`!`"1\?QMX.&```$@`)CF`8P``2``C(4@`)4U_Y/MX?&4;>#A@
M``-(`"-M+X,``$&>`"2``0`D@^$`'#A@```X(0`@?`@#IDZ``"!@````8```
M`$@`)?&`8P``2``BV4@`)06``P`05``$)B^`0`!!G@`L.&```$@`)<V`8P``
M2``BM4@`).&!(P`052D$)FT@__\O@*``0)[_G'_C^W@X@``"2``C`8`!`"2#
MX0`<."$`('P(`Z9\8P`T5&/9?DZ``""4(=_0?`@"II/A("R3P2`HD`$@-).A
M("0[X1`;@`*/^)`!(!PX````2``@^3S`$``]`!``?&<;>#C&6JPY"%JX?^/[
M>#B```$XH!`!3,8Q@D@`)0$O@P``0)P`2#O@``"!(2`<@`*/^'TI`GDX````
M?^/[>$""`'"``2`T@Z$@)(/!("B#X2`L."$@,'P(`Z9.@``@8````&````!@
M````.\$`&G_C^WA_Q/-X.*`0`$@`)`%\?1MY08#_I#A]``%(`".!?'\;>4&"
M_YA_Q/-X?Z7K>$@`(JTX````?!_IKDO__X!(`"-]8````&````"4(?_P."$`
M$$O__PA@````E"'_P'P(`J:3@0`PDZ$`-'Q]&WB3P0`XD^$`/)`!`$23(0`D
MDT$`*)-A`"R(!```:!\`/2/_``!_Y`&4?^/[>$@`(F$X@0`<?'P;>'^CZWA,
MQC&"2__V'7Q^&WE!@@!D2``B03D@``!_G!A`09T"`'P?2*Y\'DFN.2D``2^`
M``!`GO_P@`$`1(,A`"0X8```@T$`*(-A`"Q\"`.F@X$`,(.A`#2#P0`X@^$`
M/#@A`$!.@``@8````&````!@````/V`0`CO````X@``(@'O!8'QI&WB``P``
M+X```$&>`!R$"0`$.]X``2^```!`GO_T.)X``E2$$#H](!`"@`G!C"^```!!
MG@!,2``?B5?9$#HO@P``?'H;>)![P6!`G@!@@`$`1(,A`"0X8/__@T$`*(-A
M`"Q\"`.F@X$`,(.A`#2#P0`X@^$`/#@A`$!.@``@.````7R#(WB0"<&,2``A
MY7QZ&WE!@O^\5]D0.H";P6!_)<MX2``B39-;P6`X'@`!.2```%0`$#I].@$N
MD\$`'(@=```O@```09X`Y"^``#U!G@#<?ZGK>$@```Q@````09H`%(P)``$O
M@```+P``/4">__!]/4A0.'P``H/;P6!\8TH42``A;2^#``!\?LDN09[_0#T@
M$`*('0``+X```(%IP6"!(0`<52D0.GTK2"Z8"0``09X`."^``#U!G@`P.[T`
M`4@``!!@````8````$&:`!R('0``.[T``9P)``$O@```+P``/4">_^@X```]
M.6```)@)``!@````8````'P?6*Y]25H4.6L``2^```"8"@`!0)[_[$O__AR#
M(0`</V`0`E<Y$#I+__\8.2```$O__TA@````8````&`````](!``E"'_L#DI
M6?Q\"`*FD^$`3)/!`$B0`0!4DZ$`1'Q]&WB#Z0`$@`D`&),!`#"3(0`T@.D`
M"($)``R300`XDV$`/(%)`!"!:0`4DX$`0)#A`!R1`0`@D4$`))%A`"B0`0`L
MD^$`&(@?```O@```09X`B#]@$`"#B0`<.\$`'#M[6KQ(```L8````&````!(
M`"`1+X,``$&>`)B#_@``.]X`!(@?```O@```09X`3'_C^WA,QC&"2__T27^D
MZWA\>1MY08(`$(@9```O@```0)[_P'_C^WA_I.MX3,8Q@DO__)&#_@``.]X`
M!(@?```O@```0)[_O(`!`%2#`0`P@R$`-(-!`#A\"`.F@V$`/(.!`$"#H0!$
M@\$`2(/A`$PX(0!03H``(&````!@````?Z/K>$@`'MU\>!MX?X/C>$@`'M%\
M>AMX?R/+>$@`'L5].-(4.`D``7Q@&A1(`!]5?RG+>#B```$XH/__?V;;>'QZ
M&WA_I^MX?XCC>$S&,8)(`"!!?^/[>']$TWA,QC&"2__[X4O__PA@````8```
M`)0A_[`\@!``?`@"ICB$6?PXH``BDX$`0).A`$0XA``@/Z`0`)/!`$B3X0!,
M/^`0`#N]6PB0`0!4._]:[#_`$``[WEJ(/X`0`#N<6Q0X80`:@`*/^)`!`#PX
M````2``=]3Q@$``X8UK$3,8Q@DO_\\4\8!``.&-:T$S&,8)+__.U/&`0`#AC
M6MA,QC&"2__SI3Q@$``X8UKD3,8Q@DO_\Y5_X_MX3,8Q@DO_\XD\8!``.&-:
M_$S&,8)+__-Y?Z/K>$S&,8)+__-M?\/S>$S&,8)+__-A?X/C>$S&,8)+__-5
M/&`0`#AC6R!,QC&"2__S13Q@$``X8ULL3,8Q@DO_\S4\8!``.&-;/$S&,8)+
M__,E/&`0`#AC6TA,QC&"2__S%3Q@$``X8UM43,8Q@DO_\C5\9!MY08(`$'^#
MXWA,QC&"2__ZD3Q@$``X8UMH3,8Q@DO_\A%\9!MY08(`%#Q@$``X8UM\3,8Q
M@DO_^FD\8!``.&-;B$S&,8)+__'I?&0;>4&"`&!_H^MX3,8Q@DO_^D4\@!``
M?^/[>#B$6[A,QC&"2__Z,8$A`#R``H_X?2D">3@```!`@@",@`$`5(.!`$"#
MH0!$@\$`2'P(`Z:#X0!,."$`4$Z``"!@````8````#Q@$``X8UN83,8Q@DO_
M\75\9!MY08(`''_#\WA,QC&"2__YT4O__XQ@````8````#R`$``X80`K.(1;
MK#B@``I(`!W1+X,``$">_VA_P_-X.($`-4S&,8)+__F92___5$@`'/%@````
M8````&````"4(?_P?`@"II`!`!1(`!Q52``<,3@````L`P``08(`"(`#``!\
M`P-X@`$`%#@A`!!\"`.F3H``(&````!@````E"'_X'P(`J:3P0`8D^$`''Q^
M&WF0`0`D08(`N(@>```O@```09X`K$@`&[D]0!``.`/__WR^`A1_GBA`0)P`
M2($J6?Q]?@"NB2D``'^+2`!`G@#`?'X:%'P>*%`X8__^?YX80'P)`Z9`O0`4
M2``!D(@%``!_@%@`0)X`F#BE__]"`/_P?X7P`$">`,2`:EG\B24``(@#``!_
MB0``09X!)$@`'6%\?QMX@`$`)(/!`!A_X_MX@^$`'#@A`"!\"`.F3H``(&``
M``!@````8````#A@``)(`!NM?'\;>4&"_\PX`"X`?^/[>+`?``"``0`D@\$`
M&(/A`!PX(0`@?`@#IDZ``"!@````8````&`````X!?__?YX`0'P>*%!\"0.F
M09T`T"^>__]`O@`42```Q(@%``!_@$@`09[_3#BE__]"`/_P?X7P`$&>_T0X
M!?__@6I9_'^>`$!\'BA0?`D#ID&=`(0OGO__09X`?&`````XI?__0D``%(@+
M``"))0``?XD``$&>_^Q\OBA0.^```#@%``(K@!``09W_$#_@$`)_Q/-X.__!
MC#BE``$[_P`$.,`0`'_C^WA(`!?92__^[#A@``([X```2``:N2P#``!!@O[8
M.``N`'Q_&WBP`P``2__^R#@```%\"0.F2___A#@```%\"0.F2___1#@```%\
M"0.F2__^>&````!@````E"'_X'P(`J:3P0`8D^$`''Q^&WB0`0`D2__]V8@#
M``!\?QMX+X```$&>`$0](!``.&,``8$I6?R)*0``2```%(@#```X8P`!+X``
M`$&>`"!_@$@`0)[_[(@#``!\?QMX.&,``2^```!`GO_H2__NA2^#``!!G@`P
M+YX``$&>`"B('@``+X```$&>`!P\@!``?^/[>#B$6[Q(`!G)?Y\8`$&>`!R`
M`0`D@\$`&(/A`!PX(0`@?`@#IDZ``""``0`D@^$`''_#\WB#P0`8."$`('P(
M`Z9+__+,8````&````"4(?_0?`@"II!A`!R0@0`8D*$`%)`!`#23X0`LD\$`
M*#AA`!PX@0`8.*$`%$@`&I4\@!``/&`0`#B$4Z`X8U5P?(4C>$@`%&TX8```
M2``7I8OC```OGP``0)X`-$@`%X4](!`"+X,``)!IT9!!G@)`2``803A@``!(
M`!I9@&,``$@`%T%(`!FMF^,``#A@``!(`!I!@&,``$@`%RE(`!I%?&D;>#A@
M``"("0``8````I@)``!(`!H=@&,``$@`%P5(`!HA/2`0`,`)6G0](!``B`,`
M`&````&8`P``/`!#,)`!``B`80`<.&,`!9!A``S)H0`(_:T`*,@)6G@](!``
M_:T`*L@)6H#_C0``09T!B#_@$`)48Q`Z.__!C$@`&26!`0`8@*$`'#U@$``O
MA0`!?&D;>)!_$`B`"```D`,``#@+6\0]8!``D`,`!#@+77P]8!``D`,`"#@+
M6\B0`P`,.```!)`?$`Q`G0`L.`7__SE@``1\"0.F8````&````!]25H4?`A8
M+CEK``20"@`,0@#_\#BE``,Y8```@'\0!%2@$#H\@!``?29+>#B$42`XX```
M?6D!+D@`%/E\?AMY08(`4(!_$`1(`!>I/&`0`#AC6OQ,QC&"2__L"2^#``!!
MG@!<@'\0!$@`%*E(`!9U@`$`-(/A`"Q_P_-X@\$`*#@A`#!\"`.F3H``(&``
M``"`?Q`$2``5/7Q^&WB`?Q`$2``743Q@$``X8UK\3,8Q@DO_Z[$O@P``0)[_
MK(!_$!`O@P``09X`,$O__-F`?Q`$2``404@`%@V``0`T@^$`+'_#\WB#P0`H
M."$`,'P(`Z9.@``@/&`0`#AC6PA,QC&"2__K82^#``"0?Q`009[_6$O__[@\
M8!``/(`0`CAC6_@XA,%P3,8Q@D@`%WDX8``!2``8<6````!@````8````'V`
M`":4(>^P?`@"II-A$#R3@1!`DZ$01)/!$$A\?1MX/&`0`)/A$$R1@1`@.&-;
M"'R>(WB0`1!4DJ$0))+!$"B2X1`LDP$0,),A$#2301`X@`*/^)`!$!PX````
M3,8Q@DO_ZL$](!``.XE9_'Q[&WB#Z5G\?Z/K>'_D^WA(`!9%+X,``$&>`'0\
M8!``?Z3K>#AC6RQ,QC&"2__R^8$A$!R``H_X?2D">3@```!_H^MX0((!W(`!
M$%2!@1`@@J$0)(+!$"A\"`.F@N$0+(,!$#!]@($@@R$0-(-!$#B#81`\@X$0
M0(.A$$2#P1!(@^$03#@A$%!.@``@?Z/K>$@`%36#7``<?'D;>']$TWA_P_-X
M2``6`7QU&WE!@O]P/N`0`#\`$``ZP```.O=;S#LY``$[&%J\8M:``"X;```[
M@0`<.\```&````!@````8````(@5```O@```0)X`"'[UNWA!D@`8?V/;>'ZD
MJWA(`!;%+X,``$&>`,A^HZMX2``4M8@?``!]-1H4B6G__W^+``!`G@`L8```
M`&````!@````F\G__X@)__XX8___.2G__XE_``!_BP``09[_Z'QY&A0O@P__
M09W^Q'ZGJW@X@``!.*`0`'\&PWA_Z/MX?ZGK>'^#XWA,QC&"2``5^3A@``!(
M`!8A@&,``$@`$PE(`!4U?X3C>'QE&W@X8``#2``2-2^#``!`G@`D2``5^8!C
M``!(`!+A2``5#8`#`!!4``0F?X"P`$&>`"`X8```?T33>$@`%-$O@P``?'4;
M>$">_P1+__XX?X/C>#B```%(`!,5+X,``$">_]0\8!``?X3C>#AC6RQ,QC&"
M2__Q&7^#XWA(`!71?'T;>$O__A1(`!1E/`#__WPL"WA@`'[0?"$!;GP(`J:0
M#``$DXS_\#^`$`!\```F.3Q9_)/L__R3S/_X.^&`\)(L_\223/_(/B$``9-,
M_^B3;/_L@*D`=(-I`$B3K/_TDRS_Y#\@$`"#R0!0@,D`5#LY6PB0#/_`DFS_
MS(#I`%B!"0!<@4D`8(%I`&22C/_0DJS_U(`)`&B`B0!L@TD`1(.I`$R2S/_8
MDNS_W($I`'"3#/_@@D*/^))1@.PZ0```DW]_1)-??T!\>QMXD]]_3)._?TA_
M(\MXD)]_4)$_?U20OW]8D-]_*)#_?RR1'W\PD5]_-)%_?SB0'W\\3,8Q@DO_
MYYU\?AMY08(`$(@>```O@```0)X'N$O_]G4N`P``?'H;>$&2!]B+V@``+YX`
M`$&>`$!(`!'Y?TG3>#E``%]@````8````&````"!8P``5]X(/'P+\BYP$P@`
M0((`")E)``"/R0`!+YX``$">_^"`?W\HB`,``"^```!!G@:@.]]_+$@``!Q@
M````@'X``#O>``2(`P``+X```$&>!H!,QC&"2__F^7Q]&WE!@O_@2__MC2^#
M``!!GO_4?Z/K>$@`%`U\>!MY08+_Q'\#PWA(`!'=?'T;>']#TWA(`!'1?[T:
M%#N]!`1_H^MX2``287Q^&WA_H^MX2``258.<6?P\P!``/2`0`'\'PW@XQEO0
M.2E;O']*TW@XH/__?XCC>'Q]&W@X@``!3,8Q@D@`$S$X@`'M?Z/K>$@`#P4\
M8!``?]CS>#AC76!,QC&"2__F42^#``!!G@:8@UL``$@`$W%\9!MX?T/3>$O_
M^Q5\>AMY08(&?']#TWA(`!$U+X,``WQW&WA`G0!(.&/__#R`$`!\>AH4.(1;
MW$@`$Q4O@P``0)X`+"^7``1!G@74?OJZ%(@<``")-__[?XD``$&>!<!@````
M8````&````!_6]-X2__E_2^#``!!G@%4/(`0`#Q@$``XA%NX.&-:B$S&,8)+
M_^X=/V`0`#]`$`!(``XQ.WM;P#S`$``XQEP$.(```7QI&W@XH/__?\/S>'^G
MZWA_B.-X?VK;>$S&,8)(`!(Q.UI<%#O@``!(``!(2``-T8`#```O@``10)X`
M3$@`#>$[_P`!.(```9-A``@XH/__?T;3>'QI&WA_I^MX?\/S>'^(XWA_ZOMX
M3,8Q@D@`$>%_P_-X.(`![4@`#;4O@___09[_K'^CZWA(``\E?R/+>'_$\WA,
MQC&"2__M97_#\WA+_^_M/,$``7\#PWB`YH#L@,*/^'SG,GDXP```0((&1(%A
M``"`"P`$@8O_P((K_\2"2__(?`@#IH)K_\R"B__0?8"!((*K_]2"R__8@NO_
MW(,+_^"#*__D@TO_Z(-K_^R#B__P@ZO_](/+__B#Z__\?6%;>$Z``"!@````
M?V/;>#B```!,QC&"2``1!7QZ&WE!@OZ<.*#__SC`_^XXX``".W]_7$@`#:E_
M0]-X?V3;>#B@``9(``XIB!]_7"^```!`G@`0B!]_72^``$-!G@4,/N$``3C`
M``!_0]-X.*```#C@```[_W]<2``-93T@9T4X````82DC`9`7@&"0%X!D.,``
M`)$W@$R0%X"H/2#OS3@```!A*:N)8`"`3)$W@%`]()BZ8,:`:&$IW/Y^P0(4
MD3>`5#T@$#)A*51VD3>`6#T@P])A*>'PD3>`7'[A,A1@````8````&`````X
MH```?T/3>&"E@`!_Y/MX2``-<7Q[&WE`@0$D/.$``5=@&#B!)X!@?`!*%'^)
M`$!!G0.`@2>`9#UA``$^(0`!?_3[>(!K@*A7:Q]^?2E:%)`1@&`O@P``D3&`
M9$&>`%0@`P!`?W3;>'^;``!`G0`(?!0#>#Y!``%\=QH4?^3[>'Z%HWA(``W]
M@!*`J'P4`A0O@`!`D!*`J$">_VA^P[-X?W384'Z?HA1+_]-Y8````"^;`#]`
MG0!0.J```&````!\E*H4.*``0'[CNW@ZM0!`2``-L7[#LWA+_]-)?!784"^`
M`#]!G?_<.WO_P%=IT;XX"0`!52DP,E0`,#)^E`(4?VG84#YA``%_9=MX?H2C
M>#C``$1^X[MX2``,29-S@*@XH```?T/3>&"E@`!_Y/MX2``,47Q[&WE!@?[D
M?T/3>$@`#=$\P0`!..```&#G@/!\YPH4@^:`8(-F@&17Z>Z^?6=*%#@)``$O
M@``X.2#_@)DK_WA!G0+<?'<"%""@`#@X@```2``+K3XA``$^00`!5V=&/E=H
MA#Y7:L(^5^M&/E?IA#Y7X,(^?L.S>)CQ@*"9$8"AF5&`HIMQ@*.9<8"DF3&`
MI9@1@*:;\8"G2__253XA``&!4H!0@7*`5($R@%B`$H!<@1*`3%5WA#Y5/X0^
M51*$/E43PCZ:48#9FG&`VCI````Z8```8E*`KU5V1CY5>L(^53M&/E4'1CY5
M3$8^552$/E55PCY5(\(^5`1&/E0%A#Y4!L(^FO&`X9K1@.`^X!``8G.`V)OQ
M@.6;<8#D?^&2%#KW6_R;48#BF7&`XW_Z^W@[8```F1&`VYF1@-Q^P9H4FI&`
MW9JQ@-Z948#?F'&`YIDQ@.>8D8#HF+&`Z9C1@.J8$8#KF/&`V$@```A\]MBN
M?T/3>#B```$XH/__?N:[>$S&,8)(``V9+YL`$SM:``([>P`!0)[_V#[A``$X
M````/,`0`#U`$``XQEOL?XCC>)@7@-=_Z?MX.4I;P'_#\W@X@``!.*#__W^G
MZWA,QC&"2``-34O_^X!@````@]]_0#N_?T0[````B!X``"^```!`G@`@2__Y
MF&````"#W0``.[T`!(@>```O@```09[Y@'_#\W@[````2__FY2^#``!!GO_<
M?\/S>$@`#65\>!MY08+_S$O_^5A@````@WL`!"^;``!!GOI(?V/;>$@`"R$K
M@P`#0)WZ.#AC__P\@!``?'L:%#B$6^1(``T%+X,``$&>^B!+__H88````#U!
M``&!*H!D.2D``4O__'Q+_^K1?\/S>$@`#/E\>!MX2__ZV&````!@````8```
M`(-;``!+__F$8````&````"`?W]0B`,``"^```!!G@!(.]]_5&````!@````
M8````$S&,8)+_]]]+X,``$&>`!!(``RA?'H;>"X#``!`DO?P@'X``#O>``2(
M`P``+X```$">_]`_0!``.UI<*$O_^!@@H`!`.(```'QW`A1(``C5?L.S>$O_
MS[U^X[MX.(```#B@`#A(``B]2__]$(@??UXO@`!!0)[Z\(@??U\O@`!#0)[Z
MY(@??V`O@`!(0)[ZV(@??V$O@`!%0)[ZS#C`_\8XX``".*#__W]#TWA(``@U
M?V3;>']#TW@XH``I2``(M3S`$``]0!``.,9;['^(XWA_:=MX.4I;P'_#\W@X
M@``!.*#__W^GZWA,QC&"2``+54O_^8A(``I=8````&````"4(?_0.&```'P(
M`J:300`8DV$`')`!`#23@0`@DZ$`))/!`"B3X0`L2``+28!C``!(``@Q2``(
MK3@```&8`P``/&`0`#AC6NQ,QC&"2__>-2P#``!!@@`0B`,``"^``#%!G@*`
M2__JO3A@``!(``L%@&,``$@`!^T\@!``.*```3B$7#`XP``+2``'B2P#``!!
M@@*0/Z`0`H%C``P[P```.[W!C#O@``&!/1`,@VL`&"^)``%!G0`T2```K&``
M``"`B0`,?X/C>$@`"LDO@P``0)X`D($]$`P[_P`!.]X``7^)^`!`G0"`.&``
M`$@`"H6`8P``2``';7]DVWA_Q?-X.,```$@`"-U\>AMY08(`5($Z``"!71`(
M5^L0.H`)``A_BE@N<`L$`$""_Y@X8```2``*08!C``!(``<I@)H``#B@```X
MP``"2``*F7QD&WA_@^-X2``*/2^#``!!GO]X@3T0##@)__]_@/``09X!Y#A@
M``!(``G]@&,``$@`!N4\@!``.*```3B$7#@XP``%2``&@7Q_&WE!@@`\.&``
M`$@`"=&`8P``2``&N8$_``P\H!``.*5</(")``!(``9U@3\`#($I``"`"0`(
M=`D`0$""`6`X8```2``)F8!C``!(``:!/(`0`#B@``$XA%Q$.,``!4@`!AU\
M?QMY08(`/#Q@$``X8ULL3,8Q@DO_W'5\?AMY08(!?#A@``!(``E5@&,``$@`
M!CV!/P`,?\7S>(")``!(``7].&```$@`"36`8P``2``&'4@`!IDX````?&D;
M>#A@``"8"0``2``)%8!C``!(``7]2``).3@```"0`P``/&`0`#AC6PA,QC&"
M2__<`2^#``"0?1`009X!1#B``>U(``2-?&8;>4&"`!0OA@`109X`#"^&__]`
MG@$(@`$`-(-!`!B#80`<@X$`('P(`Z:#H0`D@\$`*(/A`"PX(0`P3H``(&``
M``!@````B`,``2^```!`GOU\.&```$@`"(&`8P``2``%:3R`$``XH``!.(1<
M,#C```M(``4%+`,``$""_8!@````8````#^@$`([O<&,2__^2&`````X8```
M2``(/8!C``!(``4E@3\`#(")``!(``;Y2__^B"^)``%`G?X<.^```6`````X
M8```._\``4@`"`F`8P``2``$\7]DVWA(``2)@!T0#'^`^`!!G?_<2__]Z&``
M``!(``?A@&,``$@`!,F!?P`,@3T0"("+``"`J0``2__<-4O__HB!/1`(@+T0
M$#Q@$``X8UQX@(D``$S&,8)(``;U@'T0"$O_\AV0?1`0@3\`#($I``"`"0`(
M<`L$`$&"`$R`:0`,@)T0"$@`!8F!/P`,@7T0"'Q^&WB!*0``@ZL``(`)``AP
M"P0`08(`2("I``P\8!``?Z3K>#AC7$A_QO-X3,8Q@D@`!HTX8```2``'-8!C
M``!(``0=@3\`##B@```XP``"@(D``$@`!XE+__^8.&```$@`!PV`8P``2``#
M]8$_``PXH```.,```H")``!(``=A?&4;>$O__YA@````E"'_\#A@``!\"`*F
MD`$`%$@`!M&`8P``2``#N3R`$``\H!``/,`0`#B$7,@XI55@.,9<Y$@`!HV`
M`0`4."$`$'P(`Z9.@``@8````&````"4(?_P.&```'P(`J:0`0`42``&@8!C
M``!(``-I2___E3A@``!(``9M@&,``$@``U4\P!``/(`0`#C&6\`\H!``.(1<
M\#BE3$!\QS-X.0```$@`!!&``0`4."$`$'P(`Z9.@``@````````````````
M?`@"ID*?``64(?_P.,```)/!``B0`0`4?\@"IC_>``([WNU,@3Z``"^)``!!
MG@`(@,D``$@``DV``0`4@\$`"#@A`!!\"`.F3H``(`````!.@``@8````&``
M``!@````E"'_T'P(`J9"GP`%D\$`*).A`"23(0`4DT$`&'RY*WA\FB-XDV$`
M').!`"!\>QMXD`$`-)/A`"Q_R`*F/]X``CO>[.Q+_\;I@[Z`!(.>@`!_G>!0
M?YP6<4&"`#`[X```5^`0.G]CVWA_1--X?R7+>#O_``%\'0`N?`D#IDZ`!"%_
MG^!`09S_W(`!`#2#(0`4@T$`&(-A`!Q\"`.F@X$`((.A`"2#P0`H@^$`+#@A
M`#!.@``@````````````````E"'_\'P(`J:0`0`4D^$`##_@$`([_[[4@!__
M_"^`__]!G@`D.____&````!@````?`D#IDZ`!"&$'__\+X#__T">__"``0`4
M@^$`##@A`!!\"`.F3H``(&````!@````E"'_\'P(`J:0`0`4@`$`%#@A`!!\
M"`.F3H``(``````]8!`"@6O``'UI`Z9.@`0@/6`0`H%KP`1]:0.F3H`$(#U@
M$`*!:\`(?6D#IDZ`!"`]8!`"@6O`#'UI`Z9.@`0@/6`0`H%KP!!]:0.F3H`$
M(#U@$`*!:\`4?6D#IDZ`!"`]8!`"@6O`&'UI`Z9.@`0@/6`0`H%KP!Q]:0.F
M3H`$(#U@$`*!:\`@?6D#IDZ`!"`]8!`"@6O`)'UI`Z9.@`0@/6`0`H%KP"A]
M:0.F3H`$(#U@$`*!:\`L?6D#IDZ`!"`]8!`"@6O`,'UI`Z9.@`0@/6`0`H%K
MP#1]:0.F3H`$(#U@$`*!:\`X?6D#IDZ`!"`]8!`"@6O`/'UI`Z9.@`0@/6`0
M`H%KP$!]:0.F3H`$(#U@$`*!:\!$?6D#IDZ`!"`]8!`"@6O`2'UI`Z9.@`0@
M/6`0`H%KP$Q]:0.F3H`$(#U@$`*!:\!0?6D#IDZ`!"`]8!`"@6O`5'UI`Z9.
M@`0@/6`0`H%KP%A]:0.F3H`$(#U@$`*!:\!<?6D#IDZ`!"`]8!`"@6O`8'UI
M`Z9.@`0@/6`0`H%KP&1]:0.F3H`$(#U@$`*!:\!H?6D#IDZ`!"`]8!`"@6O`
M;'UI`Z9.@`0@/6`0`H%KP'!]:0.F3H`$(#U@$`*!:\!T?6D#IDZ`!"`]8!`"
M@6O`>'UI`Z9.@`0@/6`0`H%KP'Q]:0.F3H`$(#U@$`*!:\"`?6D#IDZ`!"`]
M8!`"@6O`A'UI`Z9.@`0@/6`0`H%KP(A]:0.F3H`$(#U@$`*!:\",?6D#IDZ`
M!"`]8!`"@6O`D'UI`Z9.@`0@/6`0`H%KP)1]:0.F3H`$(#U@$`*!:\"8?6D#
MIDZ`!"`]8!`"@6O`G'UI`Z9.@`0@/6`0`H%KP*!]:0.F3H`$(#U@$`*!:\"D
M?6D#IDZ`!"`]8!`"@6O`J'UI`Z9.@`0@/6`0`H%KP*Q]:0.F3H`$(#U@$`*!
M:\"P?6D#IDZ`!"`]8!`"@6O`M'UI`Z9.@`0@/6`0`H%KP+A]:0.F3H`$(#U@
M$`*!:\"\?6D#IDZ`!"`]8!`"@6O`P'UI`Z9.@`0@/6`0`H%KP,1]:0.F3H`$
M(#U@$`*!:\#(?6D#IDZ`!"`]8!`"@6O`S'UI`Z9.@`0@/6`0`H%KP-!]:0.F
M3H`$(#U@$`*!:\#4?6D#IDZ`!"`]8!`"@6O`V'UI`Z9.@`0@/6`0`H%KP-Q]
M:0.F3H`$(#U@$`*!:\#@?6D#IDZ`!"`]8!`"@6O`Y'UI`Z9.@`0@/6`0`H%K
MP.A]:0.F3H`$(#U@$`*!:\#L?6D#IDZ`!"`]8!`"@6O`\'UI`Z9.@`0@/6`0
M`H%KP/1]:0.F3H`$(#U@$`*!:\#X?6D#IDZ`!"`]8!`"@6O`_'UI`Z9.@`0@
M/6`0`H%KP0!]:0.F3H`$(#U@$`*!:\$$?6D#IDZ`!"`]8!`"@6O!"'UI`Z9.
M@`0@/6`0`H%KP0Q]:0.F3H`$(#U@$`*!:\$0?6D#IDZ`!"`]8!`"@6O!%'UI
M`Z9.@`0@/6`0`H%KP1A]:0.F3H`$(#U@$`*!:\$<?6D#IDZ`!"`]8!`"@6O!
M('UI`Z9.@`0@/6`0`H%KP21]:0.F3H`$(#U@$`*!:\$H?6D#IDZ`!"`]8!`"
M@6O!+'UI`Z9.@`0@/6`0`H%KP3!]:0.F3H`$(#U@$`*!:\$T?6D#IDZ`!"`]
M8!`"@6O!.'UI`Z9.@`0@/6`0`H%KP3Q]:0.F3H`$($@``4!(``$\2``!.$@`
M`31(``$P2``!+$@``2A(``$D2``!($@``1Q(``$82``!%$@``1!(``$,2``!
M"$@``01(``$`2```_$@``/A(``#T2```\$@``.Q(``#H2```Y$@``.!(``#<
M2```V$@``-1(``#02```S$@``,A(``#$2```P$@``+Q(``"X2```M$@``+!(
M``"L2```J$@``*1(``"@2```G$@``)A(``"42```D$@``(Q(``"(2```A$@`
M`(!(``!\2```>$@``'1(``!P2```;$@``&A(``!D2```8$@``%Q(``!82```
M5$@``%!(``!,2```2$@``$1(``!`2```/$@``#A(```T2```,$@``"Q(```H
M2```)&````!@````8````&````!@````8````&````!@````/8`0`CUK\`"`
M#+_X.6NGT'P)`Z9\"UH4@8R__'U@6A1.@`0@8````&````!@````8````&``
M``!@````8````)0A__!\"`*FD`$`%)/!``A"GP`%?\@"IC_>``$[WF8P2_^_
MT8`!`!1\"`.F@\$`"#@A`!!.@``@$`)!4!``/.`0`%'P$`!1X``"``$0`%T(
M$`!=0!``75`0`%U8$`!=8!``76@0`%O`$`!=/%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@`````!``72P0`%TT$`!;S!``6\`0`%M\$`!;@!``
M72`0`%L,$`!=*!``6\`0`%T,$`!=%!``6\!9@`````````````!!S____X``
M`%!!4E]#3$5!3@```"]P<F]C+W-E;&8O97AE```E<R\E<P```"]P<F]C+R5I
M+R5S`&5X90`E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`
M````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27U1%
M35``````4$%27T1%0E5'````4$%27T-!0TA%````4$%27U!23T=.04U%````
M`%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````
M4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````<&%R+0``
M```M90``+2T``"X````E<R5S)7,E<P````!P87)L`````"YP87(`````)7,E
M<V-A8VAE+25S)7,``"4P,G@`````)7,E<W1E;7`M)74E<P```"5S)7-T96UP
M+25U+25U)7,`````4UE35$5-``!!4D=6`````!@```!P97)L`````#`````E
M<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN
M"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,```!);G1E<FYA;',Z.E!!
M4CHZ0D]/5``````O````55-%4@````!54T523D%-10````!414U01$E2`%1-
M4`!#.EQ414U0`"]T;7``````.@```$Q$7TQ)0E)!4EE?4$%42`!,24)0051(
M`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42````",A+W5S<B]B
M:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@
M;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E
M('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@
M(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$
M;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E
M('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A
M<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@
M=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I
M8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI
M;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B
M;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD
M"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@
M;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG
M="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P
M<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T
M:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@
M("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@
M("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)
M3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F
M("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@
M("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@
M;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@
M)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D[
M"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL
M96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@
M("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[
M4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'
M5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!
M4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@
M>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD
M7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O
M;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T
M96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN
M9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@
M("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO
M;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@
M("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@
M+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U
M;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*
M("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@
M("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@
M;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN
M86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@
M("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I
M(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U
M="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@
M("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@
M("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E
M>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^
M("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@
M("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@
M("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@
M?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@
M(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME
M>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@
M("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D
M=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@
M("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I
M;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I
M;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F
M:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@
M("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M
M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@
M8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B
M:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG
M(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&
M:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@
M("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F
M:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3
M:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@
M("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@
M('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@
M?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R
M(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@
M('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@
M("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@
M("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P
M(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E
M(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U
M;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O
M;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@
M;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@
M0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'
M5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=)
M)RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@
M("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@
M("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U
M="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@
M("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@
M("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2![
M"B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@
M(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI
M=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@
M("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O
M<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII
M9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG
M?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II
M<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E
M96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<
M4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N
M9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF
M("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@
M("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2
M/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T
M*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@
M)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W
M-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D
M+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[
M"B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@
M/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A
M;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@
M("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@
M/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L
M97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U
M;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@
M;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@
M("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@
M("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@
M("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@
M?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@
M9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@
M96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L
M:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@
M;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B
M;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I
M;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3
M=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@
M86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@
M("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@
M(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I
M;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@
M("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@
M("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@
M("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<
M6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@
M("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@
M("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL
M92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E
M;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*
M("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@
M("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@
M("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@
M(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV
M:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K
M<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@
M("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N
M86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@
M("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@
M("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]
M"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M
M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H
M95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@
M("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X
M(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C
M='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE
M7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@
M("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M
M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@
M("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N
M86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@
M("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!
M4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A
M;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS
M,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*
M("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@
M("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@
M("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@
M(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@
M("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@
M("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@
M("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@
M("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@
M("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@
M("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@
M("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC
M($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM[
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M
M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"
M87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@
M(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP
M871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I
M=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@
M("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R
M97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER
M92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@
M17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I
M<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&
M:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER
M92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)
M3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U
M:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE
M($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M
M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E
M;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@
M("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@
M("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@
M("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N
M("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@
M86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA
M;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R
M:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U
M:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D
M<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?
M+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W
M-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F
M:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@
M("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@
M<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]
M?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G
M(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF
M("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M
M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%
M04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@
M("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R
M7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@
M("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D
M9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M
M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H
M+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E
M='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92![
M"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@
M/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@
M(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@
M("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@
M("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B
M(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C
M:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E
M('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*
M("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6
M>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?
M5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@
M?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K
M(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*
M<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G
M9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@
M96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI
M=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@
M("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D[
M"GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A
M8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*"C$["@HC;&EN92`Q,#$R"@I?7T5.1%]?"@```'!A<BYP;````1L#
M.P```!`````!__]@`````"@````0``````%Z4@`$?$$!&PP!`````!`````8
M__]?T````"0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#_____`````/____\``````````!`!
MP4@0`;[0$`&^T`````$````!`````0```K(````!```"O0````$```+'````
M`0```Q8````!```$9`````P0`!D<````#1``6;`````$$``!J&___O40``4$
M````!1``#9P````&$``&7`````H```82````"P```!`````5``````````,0
M`<```````@```\`````4````!P```!<0`!5<<````!`!O_0````'$``5.```
M``@```/D````"0````QO___^$``4F&____\````";___\!``$ZX`````````
M````````````````````````````````````````````````````````````
M$`&^\```````````$`!8,!``6#00`%@X$`!8/!``6$`0`%A$$`!82!``6$P0
M`%A0$`!85!``6%@0`%A<$`!88!``6&00`%AH$`!8;!``6'`0`%AT$`!8>!``
M6'P0`%B`$`!8A!``6(@0`%B,$`!8D!``6)00`%B8$`!8G!``6*`0`%BD$`!8
MJ!``6*P0`%BP$`!8M!``6+@0`%B\$`!8P!``6,00`%C($`!8S!``6-`0`%C4
M$`!8V!``6-P0`%C@$`!8Y!``6.@0`%CL$`!8\!``6/00`%CX$`!8_!``60`0
M`%D$$`!9"!``60P0`%D0$`!9%!``61@0`%D<$`!9(!``6200`%DH$`!9+!``
M63`0`%DT$`!9.!``63P0`%E`$`!91!``64@0`%E,$`!94!``6500`%E8$`!9
M7!``66`0`%ED$`!9:!``66P```````````````#_____$`"Y:```6^E'0T,Z
M("A58G5N='4@-"XT+C0M-'5B=6YT=3$I(#0N-"XT`$$````39VYU``$````+
M!`$(`0P"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N
M9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV
M97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F=O=#(`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N<V1A=&$`+F)S<P`N8V]M;65N=``N9VYU+F%T=')I8G5T97,`````````
M``````````````````````````````````````````````````````L````!
M`````A```50```%4````#0```````````````0`````````3````!P````(0
M``%D```!9````"````````````````0`````````(0````<````"$``!A```
M`80````D```````````````$`````````#@````%`````A```:@```&H```#
M7`````8`````````!`````0````T;___]@````(0``4$```%!````5@````&
M``````````0````$````/@````L````"$``&7```!EP```=`````!P````$`
M```$````$````$8````#`````A``#9P```V<```&$@```````````````0``
M``````!.;____P````(0`!.N```3K@```.@````&``````````(````"````
M6V____X````"$``4F```%)@```"@````!P````(````$`````````&H````$
M`````A``%3@``!4X````)`````8`````````!`````P```!T````!`````(0
M`!5<```57````\`````&````&`````0````,````?@````$````&$``9'```
M&1P```!,```````````````$`````````(0````!````!A``&7```!EP``!`
M0```````````````$`````````"*`````0````80`%FP``!9L````#@`````
M``````````0`````````D`````$````"$`!9Z```6>@``%^(````````````
M```(`````````)@````!`````A``N7```+EP````%```````````````!```
M``````"F`````0````(0`+F$``"YA````"P```````````````0`````````
ML`````$````#$`&^T```OM`````(```````````````$`````````+<````!
M`````Q`!OM@``+[8````"```````````````!`````````"^`````0````,0
M`;[@``"^X`````0```````````````0`````````PP````$````#$`&^Y```
MON0````,```````````````!`````````,D````&`````Q`!OO```+[P```!
M``````<`````````!`````@```#2`````0````,0`;_P``"_\````!``````
M``````````0````$````>0````$````#$`'`````P`````%`````````````
M```$`````````-<````!`````Q`!P4```,%`````$```````````````!```
M``````#=`````0````,0`<%0``#!4`````@```````````````0`````````
MY`````@````#$`'!8```P5@``!!````````````````0`````````.D````!
M````,````````,%8````(P```````````````0````$```#R;___]0``````
M``````#!>P```!0```````````````$``````````0````,`````````````
6P8\```$"```````````````!````````
